#!/usr/bin/env bash

# Setup script environment
set -o errexit  #Exit immediately if a pipeline returns a non-zero status
set -o errtrace #Trap ERR from shell functions, command substitutions, and commands from subshell
set -o nounset  #Treat unset variables as an error
set -o pipefail #Pipe will exit with last non-zero status if applicable
shopt -s expand_aliases
alias die='EXIT=$? LINE=$LINENO error_exit'
trap die ERR
trap 'die "Script interrupted."' INT

function error_exit() {
  trap - ERR
  local DEFAULT='Unknown failure occured.'
  local REASON="\e[97m${1:-$DEFAULT}\e[39m"
  local FLAG="\e[91m[ERROR:LXC] \e[93m$EXIT@$LINE"
  msg "$FLAG $REASON"
  exit $EXIT
}
function msg() {
  local TEXT="$1"
  echo -e "$TEXT"
}

# Prepare container OS
sed -i "/$LANG/ s/\(^# \)//" /etc/locale.gen
locale-gen >/dev/null
apt-get -y purge openssh-{client,server} >/dev/null
apt-get autoremove >/dev/null

# Update container OS
apt-get update >/dev/null
apt-get -qqy upgrade &>/dev/null

# Install prerequisites
apt-get -qqy install \
    curl &>/dev/null

# Customize Docker configuration
DOCKER_CONFIG_PATH='/etc/docker/daemon.json'
mkdir -p $(dirname $DOCKER_CONFIG_PATH)
cat >$DOCKER_CONFIG_PATH <<'EOF'
{
  "log-driver": "journald"
}
EOF

# Install Docker
sh <(curl -sSL https://get.docker.com) &>/dev/null

# Configuring docker-compose
LINUXSERVER_DOCKERCOMPOSE='https://raw.githubusercontent.com/linuxserver/docker-docker-compose/master/run.sh'
DOCKERCOMPOSE_LOCATION='/usr/local/bin/docker-compose'
curl -L --fail $LINUXSERVER_DOCKERCOMPOSE -o $DOCKERCOMPOSE_LOCATION &>/dev/null
chmod +x $DOCKERCOMPOSE_LOCATION

# Installing Portainer,VSCode,Watchtower docker-compose
FOLDER_PORTAINER='/docker/portainer'
FOLDER_VSCODE='/docker/vscode'
STACK_OLD='/docker-compose.yml'
STACK_NEW='/docker/docker-compose.yml'
mkdir -p $(dirname $FOLDER_PORTAINER)
mkdir -p $(dirname $FOLDER_VSCODE)
mv $STACK_OLD $STACK_NEW
cd /docker;docker-compose up -d

# Customize container
rm /etc/motd # Remove message of the day after login
rm /etc/update-motd.d/10-uname # Remove kernel information after login
touch ~/.hushlogin # Remove 'Last login: ' and mail notification after login
GETTY_OVERRIDE="/etc/systemd/system/container-getty@1.service.d/override.conf"
mkdir -p $(dirname $GETTY_OVERRIDE)
cat << EOF > $GETTY_OVERRIDE
[Service]
ExecStart=
ExecStart=-/sbin/agetty --autologin root --noclear --keep-baud tty%I 115200,38400,9600 \$TERM
EOF
systemctl daemon-reload
systemctl restart $(basename $(dirname $GETTY_OVERRIDE) | sed 's/\.d//')

# Cleanup container
rm -rf /setup.sh /var/{cache,log}/* /var/lib/apt/lists/*